/***************************** C HEADER FILE *********************************
**
**  Project:    RTCU Communication Hub, Blacklist plug-in
**  Filename:   LOCAL.H 
**  Version:    1.00
**  Date:       January 30, 2019
**  
******************************************************************************
**
**  VERSION HISTORY:
**  ----------------
**  1.00 - January 30, 2019 - Michael Olsen
**  - Ported to RCH.
**
*****************************************************************************/
#if !defined(_LOCAL_H_)
#define _LOCAL_H_


/*****************************************************************************
**
**    MODULES USED 
**
*****************************************************************************/


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/


/****************************************************************************
** 
**    EXPORTED VARIABLES
**
****************************************************************************/


/****************************************************************************
**
**    EXPORTED FUNCTIONS
**
****************************************************************************/

/////////////////////////////////////////////////////////////////////////////
// This function will write an entry into the RCH log.
//
// Input:
//    type          - The type of log entry.
//                    1 = Error, 2 = Event, 3 = detailed event
//    text          - Pointer to the zero terminated UTF-8 string to enter.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void write_log(const int type, const char *text);

/////////////////////////////////////////////////////////////////////////////
// This function will initialize the black list functionality.
//
// Input:
//    config        - Pointer to the configuration string from the RCH.
//
// Output:
//    None.
//
// Returns:
//    0             - Plug-in is initialized.
//    1             - Illegal configuration string.
//    2             - No file specified in configuration.
//    3             - XML file with blacklist is not found.
//
/////////////////////////////////////////////////////////////////////////////
int  InitBlacklist(const char *config);

/////////////////////////////////////////////////////////////////////////////
// This function will stop the blacklist and cleanup resources.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void StopBlacklist(void);

/////////////////////////////////////////////////////////////////////////////
// This function is called from the Gateway when a login request is received
// from a client.
//
// Input:
//    NodeID        - The requested Node ID.
//    addr          - The IP address of the client. (As '192.168.0.1')
//    port          - The IP port of the client.
//
// Output:
//    None.
//
// Returns:
//    0             - The login is denied.
//    1             - The login is accepted.
//
/////////////////////////////////////////////////////////////////////////////
int  OnLogon(const long NodeID, const char *addr, const unsigned short port);


#endif   /* _LOCAL_H_ */
/****************************************************************************
**
**    EOF 
**
****************************************************************************/
